@@ -51,7 +51,7 @@ class SimpleMessage:
         body = self.message["body"]
 
         try:
-            match = f"^{self.bot.nick}.?(\s)"
+            match = fr"^{self.bot.nick}.?(\s)"
             split = re.split(match, body)
             filtered = list(filter(None, split))
             return filtered[-1].strip()
@@ -109,6 +109,31 @@ class Config:
         """The nickname of the bot."""
         return self.section.get("nick", None)
 
+    @property
+    def avatar(self):
+        """The avatar of the bot."""
+        return self.section.get("avatar", None)
+
+    @property
+    def redis_url(self):
+        """The Redis connection URL."""
+        return self.section.get("redis_url", None)
+
+    @property
+    def rooms(self):
+        """A list of rooms to automatically join."""
+        rooms = self.section.get("rooms", None)
+
+        if rooms is None:
+            return None
+
+        return rooms.split(",")
+
+    @property
+    def no_auto_join(self):
+        """Disable auto-join when invited."""
+        return self.section.get("no_auto_join", None)
+
 
 class Bot(ClientXMPP):
     """XMPP bots for humans."""
@@ -164,11 +189,27 @@ class Bot(ClientXMPP):
             help="Nickname for the bot account",
         )
         self.parser.add_argument(
-            "-av",
-            "--avatar",
-            dest="avatar",
-            help="Avatar for the bot account",
-            default="avatar.png",
+            "-av", "--avatar", dest="avatar", help="Avatar for the bot account"
+        )
+        self.parser.add_argument(
+            "-ru",
+            "--redis-url",
+            dest="redis_url",
+            help="Redis storage connection URL",
+        )
+        self.parser.add_argument(
+            "-r",
+            "--rooms",
+            dest="rooms",
+            nargs="+",
+            help="Rooms to automatically join",
+        )
+        self.parser.add_argument(
+            "--no-auto-join",
+            default=False,
+            action="store_true",
+            dest="no_auto_join",
+            help="Disable automatically joining rooms when invited",
         )
 
         self.args = self.parser.parse_args()
@@ -197,18 +238,74 @@ class Bot(ClientXMPP):
 
     def generate_config_interactively(self):
         """Generate bot configuration."""
+        print("*" * 79)
+
+        print(
+            "Please enter the XMPP user account of your bot. ",
+            "This is often referred to as the JID (Jabbed ID). ",
+            "An example would be echobot@vvvvvvaria.org",
+            sep="\n",
+        )
         account = input("Account: ")
+
+        print("Please enter the password for your bot account")
         password = getpass("Password: ")
+
+        print("Please enter the nickname for your bot account")
         nick = input("Nickname: ")
 
+        print(
+            "Please enter the path to your avatar file",
+            "The default is an avatar.png file in the current directory",
+            "(leave empty if you want the default or have no avatar)",
+            sep="\n",
+        )
+        avatar = input("Avatar: ")
+
+        print(
+            "Please enter the connection URL of your Redis instance",
+            "(leave empty if you are not using Redis)",
+            sep="\n",
+        )
+        redis_url = input("Redis URL: ")
+
+        print(
+            "Please supply a list of rooms to automatically join",
+            "for example, foo@muc.vvvaria.org, bar@muc.vvvvvvaria.org",
+            "(leave empty if you don't want to join rooms when starting)",
+            sep="\n",
+        )
+        rooms = input("Rooms: ")
+
+        print(
+            "Please choose to disable auto-join on invite if you prefer",
+            "that your bot does not join after being invited to a room",
+            "(type 'y' to choose to disable)",
+            sep="\n",
+        )
+        no_auto_join = input("Disable auto-join on invite? ")
+
+        print("*" * 79)
+
         config = ConfigParser()
         config[self.name] = {"account": account, "password": password}
 
         if nick:
             config[self.name]["nick"] = nick
+        if avatar:
+            config[self.name]["avatar"] = avatar
+        if redis_url:
+            config[self.name]["redis_url"] = redis_url
+        if rooms:
+            config[self.name]["rooms"] = rooms
+        if no_auto_join:
+            config[self.name]["auto_join"] = (
+                True if no_auto_join == "y" else False
+            )
 
         with open(self.CONFIG_FILE, "w") as file_handle:
             config.write(file_handle)
+            self.log.info(f"Generated {self.CONFIG_FILE}")
 
     def init_bot(self):
         """Initialise bot with connection details."""
@@ -225,6 +322,27 @@ class Bot(ClientXMPP):
         nick = (
             self.args.nick or self.config.nick or environ.get("XBOT_NICK", None)
         )
+        avatar = (
+            self.args.avatar
+            or self.config.avatar
+            or environ.get("XBOT_AVATAR", None)
+            or "avatar.png"
+        )
+        redis_url = (
+            self.args.redis_url
+            or self.config.redis_url
+            or environ.get("XBOT_REDIS_URL", None)
+        )
+        rooms = (
+            self.args.rooms
+            or self.config.rooms
+            or environ.get("XBOT_ROOMS", None)
+        )
+        no_auto_join = (
+            self.args.no_auto_join
+            or self.config.no_auto_join
+            or environ.get("XBOT_NO_AUTO_JOIN", None)
+        )
 
         if not account:
             self.log.error("Unable to discover account")
@@ -241,8 +359,10 @@ class Bot(ClientXMPP):
         self.account = account
         self.password = password
         self.nick = nick
-
-        self.avatar = self.args.avatar
+        self.avatar = avatar
+        self.redis_url = redis_url
+        self.rooms = rooms
+        self.no_auto_join = no_auto_join
 
     def register_xmpp_event_handlers(self):
         """Register functions against specific XMPP event handlers."""
@@ -264,7 +384,8 @@ class Bot(ClientXMPP):
             return
 
         if message.text.startswith("@"):
-            self.command(message, to=message.sender)
+            if self.command(message, to=message.sender):
+                return
 
         try:
             self.direct(message)
@@ -276,6 +397,7 @@ class Bot(ClientXMPP):
         self.send_presence()
         self.get_roster()
         self.publish_avatar()
+        self.join_rooms()
 
     def publish_avatar(self):
         """Publish bot avatar."""
@@ -297,9 +419,24 @@ class Bot(ClientXMPP):
         self.plugin["xep_0084"].publish_avatar(contents)
         self.plugin["xep_0084"].publish_avatar_metadata(items=[info])
 
+    def join_rooms(self):
+        """Automatically join rooms if specified."""
+        if self.rooms is None:
+            return
+
+        for room in self.rooms:
+            self.plugin["xep_0045"].join_muc(room, self.config.nick)
+            self.log.info(f"Joining {room} automatically")
+
     def group_invite(self, message):
         """Accept invites to group chats."""
-        self.plugin["xep_0045"].join_muc(message["from"], self.config.nick)
+        room = message["from"]
+
+        if self.no_auto_join:
+            return self.log.info(f"Not joining {room} (disabled)")
+
+        self.plugin["xep_0045"].join_muc(room, self.config.nick)
+        self.log.info(f"Joining {room} as invited")
 
     def group_message(self, message):
         """Handle group chat message events."""
@@ -316,7 +453,8 @@ class Bot(ClientXMPP):
             return
 
         if message.content.startswith("@"):
-            self.command(message, room=message.room)
+            if self.command(message, room=message.room):
+                return
 
         try:
             self.group(message)
@@ -330,16 +468,24 @@ class Bot(ClientXMPP):
         self.register_plugin("xep_0199")  # XMPP Ping
         self.register_plugin("xep_0084")  # User Avatar
 
+        try:
+            for plugin in self.plugins:
+                self.register_plugin(plugin)
+                self.log.info(f"Loaded {plugin}")
+        except AttributeError:
+            self.log.info("No additional plugins loaded")
+
     def init_db(self):
         """Initialise the Redis key/value store."""
-        url = environ.get("REDIS_URL", None)
-
-        if not url:
+        if not self.redis_url:
             self.db = None
-            self.log.info("No storage discovered")
-        else:
-            self.db = Redis.from_url(url, decode_responses=True)
-            self.log.info("Successfully connected to storage")
+            return self.log.info("No Redis storage discovered")
+
+        try:
+            self.db = Redis.from_url(self.redis_url, decode_responses=True)
+            self.log.info("Successfully connected to Redis storage")
+        except ValueError:
+            self.log.info("Failed to connect to Redis storage")
 
     def run(self):
         """Run the bot."""
@@ -369,6 +515,7 @@ class Bot(ClientXMPP):
             kwargs["mtype"] = "groupchat"
 
         self.send_message(**kwargs)
+        return True
 
     @property
     def uptime(self):
@@ -378,17 +525,17 @@ class Bot(ClientXMPP):
     def meta(self, message, **kwargs):
         """Handle meta command invocations."""
         if message.text.startswith("@bots"):
-            self.reply("🖐️", **kwargs)
+            return self.reply("🖐️", **kwargs)
 
     def command(self, message, **kwargs):
         """Handle command invocations."""
         if message.content.startswith("@uptime"):
-            self.reply(self.uptime, **kwargs)
+            return self.reply(self.uptime, **kwargs)
         elif message.content.startswith("@help"):
             try:
-                self.reply(cleandoc(self.help), **kwargs)
+                return self.reply(cleandoc(self.help), **kwargs)
             except AttributeError:
-                self.reply("No help found 🤔️", **kwargs)
+                return self.reply("No help found 🤔️", **kwargs)
 
 
 class EchoBot(Bot):
